# LIVE_CHART_ENDPOINT = 'http://localhost:5000/live-chart'

# TODO: I guess have a local database of anime info, and if the user wants to update it/searches for something not there idk, then they can do so

TIMEOUT = 1

HEADLINE_ENDPOINT = 'https://www.livechart.me/feeds/headlines'
RECENTLY_AIRED_ENDPOINT = 'https://www.livechart.me/feeds/episodes'

LC_ENDPOINT = "https://www.livechart.me/"


QUERY = "?titles=english"

# SEARCH

SEARCH_ENDPOINT = 'https://www.livechart.me/search'